//
//  YHHomeCollectionViewCell.swift
//  galaxy
//
//  Created by EDY on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import Kingfisher

class YHHomeCollectionViewCell: UICollectionViewCell {
    static let cellReuseIdentifier = "YHHomeCollectionViewCell"
    
    var dataSource: AboutAdvantageItem? {
        didSet {
            updataAllSubViews()
        }
    }
    
    lazy var titleImageView:UIImageView = {
        let imageV = UIImageView(image: UIImage(named: "home_title_image"))
        imageV.contentMode = .scaleAspectFill
        imageV.roundCorners(UIRectCorner.topLeft, radius: 8)
        imageV.roundCorners(UIRectCorner.topRight, radius: 8)
        return imageV
    }()
    
    
    lazy var descripeLable:UILabel = {
        let label = UILabel()
        label.text = "赴港攻略，当日往返无忧，这个季节风景..赴港攻略，当日往返无忧，这个季节风景"
        label.textColor = UIColor(hexString:"#333333")
        label.font = UIFont.systemFont(ofSize: 10)
        label.numberOfLines = 2
        label.lineBreakMode = .byTruncatingTail
        return label
    }()
    
    
    lazy var headImageView:UIImageView = {
        let imageV = UIImageView(image: UIImage(named: "home_person_icon"))
        imageV.contentMode = .scaleAspectFill
        return imageV
    }()
    
    
    lazy var nameLable:UILabel = {
        let label = UILabel()
        label.text = "Fiona"
        label.textColor = UIColor(hexString:"#333333")
        label.font = UIFont.systemFont(ofSize: 10)
        return label
    }()
    
    
    lazy var dateLable:UILabel = {
        let label = UILabel()
        label.text = "12-12"
        label.textColor = UIColor(hexString:"#333333")
        label.font = UIFont.systemFont(ofSize: 10)
        return label
    }()
    
    
    lazy var heartImageView:UIImageView = {
        let imageV = UIImageView(image: UIImage(named: "home_red_heart"))
        imageV.contentMode = .scaleAspectFill
        return imageV
    }()
    
    lazy var numLable:UILabel = {
        let label = UILabel()
        label.text = "2000"
        label.textColor = UIColor(hexString:"#333333")
        label.font = UIFont.systemFont(ofSize: 14)
        return label
    }()
    
    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        setupUI()
    }
    
    private func setupUI() {
        
        contentView.backgroundColor = UIColor(hexString: "#F8F9FB")
        contentView.roundCorners([.topLeft,.topRight], radius: 4)
        contentView.clipsToBounds = true
        
        contentView.addSubview(titleImageView)
        titleImageView.snp.makeConstraints { make in
            make.left.right.top.equalToSuperview()
            make.height.equalTo(210)
        }
        
        let subHoldView = UIView()
        subHoldView.layer.backgroundColor = UIColor(red: 1, green: 1, blue: 1, alpha: 1).cgColor
        subHoldView.layer.borderWidth = 0.5
        subHoldView.layer.borderColor = UIColor(red: 0.798, green: 0.798, blue: 0.798, alpha: 1).cgColor
        contentView.addSubview(subHoldView)
        subHoldView.snp.makeConstraints { make in
            make.top.equalTo(titleImageView.snp.bottom)
            make.bottom.left.right.equalToSuperview()
        }
        
        subHoldView.addSubview(descripeLable)
        descripeLable.snp.makeConstraints { make in
            make.top.equalToSuperview().offset(10)
            make.left.equalToSuperview().offset(8)
            make.right.equalToSuperview().offset(-8)
            make.bottom.equalTo(-36)
        }
        
        subHoldView.addSubview(numLable)
        numLable.snp.makeConstraints { make in
            make.right.equalToSuperview().offset(-8)
            make.height.equalTo(12)
            make.bottom.equalTo(-10)
        }
        
        subHoldView.addSubview(heartImageView)
        heartImageView.snp.makeConstraints { make in
            make.right.equalTo(numLable.snp.left).offset(-6)
            make.height.width.equalTo(12)
            make.bottom.equalTo(-10)
        }
        
    }
    
    func updataAllSubViews() {
        guard let dataSource = dataSource else { return }
        let imageSize = getImageSize(dataSource.url)
        var imageHeight = 0.0
        if imageSize.width == 0 {
            imageHeight = width
        } else {
            imageHeight = width * imageSize.height/imageSize.width
            if imageHeight > 280 {
                imageHeight = 280
            }
        }
        titleImageView.snp.remakeConstraints { make in
            make.left.right.top.equalToSuperview()
            make.height.equalTo(imageHeight)
        }
        if let url = URL(string: dataSource.url) {
            titleImageView.kf.setImage(with: url)
        }
        descripeLable.text = dataSource.title
    }
    
    func getImageSize(_ url: String?) -> CGSize {
        guard let urlStr = url, urlStr.count != 0 else {
            return CGSize.zero
        }
        let tempUrl = URL(string: urlStr)
        let imageSourceRef = CGImageSourceCreateWithURL(tempUrl! as CFURL, nil)
        var width: CGFloat = 0
        var height: CGFloat = 0
        if let imageSRef = imageSourceRef {
            let imageProperties = CGImageSourceCopyPropertiesAtIndex(imageSRef, 0, nil)
            if let imageP = imageProperties {
                let imageDict = imageP as Dictionary
                width = imageDict[kCGImagePropertyPixelWidth] as! CGFloat
                height = imageDict[kCGImagePropertyPixelHeight] as! CGFloat
            }
        }
        return CGSize(width: width, height: height)
    }
}
