//
//  YHServiceSectionView.swift
//  galaxy
//
//  Created by EDY on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHServiceSectionView: UIView {

    var items: [String] = []
    var selectIndex = 0
    lazy var myCollectView = {
        // 设置布局方向
        let flowLayout = UICollectionViewFlowLayout()
        flowLayout.itemSize = CGSize(width: 75, height: 32)
        flowLayout.minimumInteritemSpacing = 12.0
        flowLayout.minimumLineSpacing = 12.0
        flowLayout.scrollDirection = .horizontal
        
        let collectinoView = UICollectionView(frame: .zero, collectionViewLayout: flowLayout)
        collectinoView.backgroundColor = .white
        collectinoView.contentInset = UIEdgeInsets(top: 10, left: 20, bottom: 0, right: 20)
        collectinoView.register(YHServiceSectionCollectionViewCell.self, forCellWithReuseIdentifier:YHServiceSectionCollectionViewCell.cellReuseIdentifier)
        collectinoView.delegate = self
        collectinoView.dataSource = self
        collectinoView.showsVerticalScrollIndicator = false
        
        collectinoView.translatesAutoresizingMaskIntoConstraints = false
        collectinoView.alwaysBounceVertical = true
        return collectinoView
    }()

    var dataSource: YHScemeHeadModel? {
        didSet {
            updateAllViews()
        }
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        backgroundColor = .white
        setUpView()
        self.items = ["优才","高才","留学","专才"]
        self.myCollectView.reloadData()
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func setUpView() {
        backgroundColor = .white
        addSubview(myCollectView)
        myCollectView.snp.makeConstraints { make in
            make.top.left.right.bottom.equalToSuperview()
        }
//        self.myCollectView.es.addInfiniteScrolling {
//            self.loadFakeData()
//        }
    }
    
    func updateAllViews() {
        guard let model = dataSource else { return }
    }
    
}

extension YHServiceSectionView: UICollectionViewDelegate, UICollectionViewDataSource {
    
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return items.count
    }
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: YHServiceSectionCollectionViewCell.cellReuseIdentifier, for: indexPath) as! YHServiceSectionCollectionViewCell
        cell.dataSource = items[indexPath.row]
        if indexPath.row == selectIndex {
            cell.isSelected = true
        } else {
            cell.isSelected = false
        }
        return cell
        
    }
    
    private func collectionView(collectionView: UICollectionView, didSelectItemAtIndexPath indexPath: NSIndexPath) {
        selectIndex = indexPath.row
        collectionView.reloadData()
        print("index is \(indexPath.row)")
    }
}

class YHServiceSectionCollectionViewCell: UICollectionViewCell {
    static let cellReuseIdentifier = "YHServiceSectionCollectionViewCell"
    
    private var isSelect: Bool = false
    override var isSelected: Bool {
        set {
            self.isSelect = newValue
            if newValue {
                self.setSelectedStyle()
            } else {
                self.setDeSelectedStyle()
            }
        }
        get {
            return self.isSelect
        }
    }
 
    private func setSelectedStyle() {
        contentView.backgroundColor = UIColor.brandMainColor
        descripeLable.textColor = UIColor.white
    }
 
    private func setDeSelectedStyle() {
        contentView.backgroundColor = UIColor(hex: 0xf4f6fa)
        descripeLable.textColor = UIColor(hex: 0x94a3bb)
    }
    
    var dataSource: String? {
        didSet {
            updataAllSubViews()
        }
    }
    
    lazy var descripeLable:UILabel = {
        let label = UILabel()
        label.text = "赴港"
        label.textColor = UIColor(hex: 0x94a3bb)
        label.font = UIFont.PFSC_R(ofSize: 13)
        label.textAlignment = .center
        return label
    }()

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        setupUI()
    }
    
    private func setupUI() {
        
        contentView.backgroundColor = UIColor(hex: 0xf4f6fa)
        contentView.clipsToBounds = true
        contentView.layer.cornerRadius = 16
        
        contentView.addSubview(descripeLable)
        descripeLable.snp.makeConstraints { make in
            make.top.left.right.bottom.equalToSuperview()
        }
    }
    
    func updataAllSubViews() {
        guard let dataSource = dataSource else { return }
        descripeLable.text = dataSource
    }
}
